!--------------------------------------------------------------------------------
!  Main program to run the MCMC algorithm
!
!  The input again comes from the file halo5.tab
!  The output file is generated within the acutal MCMC algorithm
!
!  And again: compile the subroutines.f90 once before you run the chain algorithm
!--------------------------------------------------------------------------------

program lensprofile
  ! The modules used py the program 
  use constants
  use cosmology
  use profile
  use inputdata
  use chi2calc
  use mcmc
  implicit none

  ! Defining the variables
  double precision :: rs, dc, conc, xtheory, sheartheory
  character(80) :: inputfile
  character(80) :: outputfile
  double precision :: rreal, creal, dreal, mreal, cmin
  integer :: i

  ! Value of Omega_matter to define the cosmological model, in our case a flat LCDM 
  cosmopar%omegam = 0.27d0

  ! Some data for the lens
  ndat = 627656
  zlens = 0.245d0
  sigmashear = 0.3d0

  dAlens = dA(zlens)
  rhoclens = rhocrit(zlens)
  
  ! Open the input file and read it in
  inputfile  ="../Data/halo5.tab"
  call readinput(inputfile)


  ! At this point you may enter your values of M_200 and c_200 calculated in the exercise before
  Mreal = 1.14d15
  creal = 3.09d0
  
  rreal = rsnfw(Mreal,creal)
  dreal = deltac(creal)
  cmin = CHI2(rreal,dreal)
  write(*,*) 'chi^2 of the real cluster values :',CMIN


  ! The following part of the program sets up the chain algorithm

  npar = 2
  ! Assign the necessary memory space 
  allocate(par(npar),dpar(npar),lobound(npar),upbound(npar),dpari(npar))
  
  ! Quick note, how PAR1 and PAR2 are treated in the following
  ! PAR1: Mass M200c in h^-1 Msun
  ! PAR2 : concentration 
 
  ! Initial Value
  par(1) = 5.0d14
  par(2) = 10.0d0

  ! Step width
  dpar(1) = 1.0d14
  dpar(2) = 0.2d0

  ! Initial step width
  dpari(1) = 5.0d14
  dpari(2) = 2.0d0

  ! Lower boundary of the parameter space
  lobound(1) = 5.0d13
  lobound(2) = 1.0d0

  ! Upper limit of the parameter space
  upbound(1) = 1.0d16
  upbound(2) = 12.0d0

  ! Number of SAMPLES in for the chain algorithm
  nsample = 100000


  ! run the chain and produce the output file
  outputfile = '../Data/chain1.dat'
  call chain(outputfile)

  ! Free the memory space
  deallocate(par,dpar,lobound,upbound)

end program lensprofile
