program lensprofile
USE CONSTANTS
USE COSMOLOGY
USE PROFILE
USE INPUTDATA
USE CHI2CALC
USE MCMC


IMPLICIT NONE

DOUBLE PRECISION :: rs,dc,conc
CHARACTER*80 :: INPUTFILE
CHARACTER*80 :: OUTPUTFILE
DOUBLE PRECISION :: rreal,creal,dreal,Mreal,cmin
DOUBLE PRECISION :: xtheory,sheartheory
INTEGER :: I

! THE COSMOLOGICAL MODEL: FLAT LCDM
cosmopar%omegam=0.27d0

! THE DATA
NDAT=627656
zlens = 0.245d0
sigmashear=0.3d0

dAlens = dA(zlens)
rhoclens=rhocrit(zlens)

INPUTFILE="../Data/halo5.tab"
CALL READINPUT(INPUTFILE)


! THE REAL VALUES FOR THE CLUSTER
Mreal = 1.14d15
creal = 3.09d0
rreal=rsnfw(Mreal,creal)
dreal=deltac(creal)
cmin = CHI2(rreal,dreal)
WRITE(*,*) 'chi^2 of the real cluster values :',CMIN


! SET UP THE CHAIN

NPAR = 2
ALLOCATE(PAR(NPAR),DPAR(NPAR),LOBOUND(NPAR),UPBOUND(NPAR),DPARI(NPAR))

! PAR1: Mass M200c in h^-1 Msun
! PAR2 : concentration 

! Initial Value
PAR(1) = 5.0d14
PAR(2) = 10.0d0

! STEP WIDTH
DPAR(1) = 1.0d14
DPAR(2) = 0.2d0

! INITIAL STEP WIDTH
DPARI(1) = 5.0d14
DPARI(2) = 2.0d0

! LOWER BOUND OF PARAMETERS
LOBOUND(1) = 5.0d13
LOBOUND(2) = 1.0d0

! UPPER BOUND OF PARAMETERS
UPBOUND(1) = 1.0d16
UPBOUND(2) = 12.0d0

! Number of SAMPLES in THE CHAIN
NSAMPLE = 100000


! RUN CHAIN
OUTPUTFILE='../Data/chain3.dat'
call chain(OUTPUTFILE)

! CLEAN UP AFTER RUN
DEALLOCATE(PAR,DPAR,LOBOUND,UPBOUND)


end program lensprofile
